@@ -234,6 +234,7 @@ PURE_FLN_SUB = (
 PURE_FLN_WILDCARD_SUB = (
     r"^" + PATH_MATCH + r" \(line " + LINENO_MATCH + r"\)$",
     r"* [\1:\2]")
+# "$file (line $lineno) $msg" => "$msg [$file:$lineno]"
 INTERTWINED_FLN_SUB = [
     (r"^" + PATH_MATCH + r" (.+) \(line (" + LINENO_MATCH + r"\)",
      r"\2 [\1:\3]"),
@@ -349,6 +350,7 @@ INFO_FIXERS = {
     "shared-library-lacks-prerequisites": PURE_FN_SUB,
     "codeless-jar": PURE_FN_SUB,
     "hardening-no-pie": PURE_FN_SUB,
+    "hardening-no-relro": PURE_FN_SUB,
     "obsolete-url-in-packaging": (
         r"^(?P<path>.+) (.+)$", r"\2 [\1]"),
     "inconsistent-appstream-metadata-license": (
@@ -356,6 +358,14 @@ INFO_FIXERS = {
         r'\1 (\2 != \3) [debian/copyright]'),
     "source-ships-excluded-file": (
         r"^([^ ]+)$", r"\1 [debian/copyright:*]"),
+    "package-installs-java-bytecode": PURE_FN_SUB,
+    "jar-not-in-usr-share": PURE_FN_SUB,
+    "debconf-is-not-a-registry": ("^" + PATH_MATCH + "$", r"[\1:*]"),
+    "unused-debconf-template": ("^([^ ]+)$", r"\1 [*:*]"),
+    "apache2-reverse-dependency-calls-invoke-rc.d": (
+        "^" + PATH_MATCH + r":([0-9]+)$", r"[\1:\2]"),
+    "application-in-library-section": (
+        "^(.+) " + PATH_MATCH + "$", r"\1 [\2]"),
 }
 
 
